import * as geojson from 'geojson';
import * as rxjs from 'rxjs';
import { BehaviorSubject, Subject } from 'rxjs';
import { HttpClient } from '@angular/common/http';
import * as _angular_core from '@angular/core';
import { DestroyRef, OnInit, OnChanges, ElementRef, SimpleChanges } from '@angular/core';
import * as i2 from '@angular/forms';
import { FormControl } from '@angular/forms';

declare class BasicGeocoderOptions {
    rows?: number;
    start?: number;
    wt?: string;
    indent?: boolean;
    lat?: number;
    lon?: number;
    fq?: string;
    fl?: string;
}
declare class SuggestOptions extends BasicGeocoderOptions {
    sort?: string;
    qf?: string;
    bq?: string;
}
declare class LookupOptions extends BasicGeocoderOptions {
}
declare class ReverseOptions extends BasicGeocoderOptions {
    type?: string;
    distance?: number;
}
interface SuggestObject {
    id: string;
    score?: number;
    type: string;
    weergavenaam: string;
}
interface SuggestObjectWithHighlight extends SuggestObject {
    highlight: string;
}
declare class ReverseGeometry {
    X?: number;
    Y?: number;
    lat?: number;
    lon?: number;
}
interface Provincie {
    bron: 'Bestuurlijke Grenzen';
    identificatie: string;
    geometrie_ll: string;
    provinciecode: string;
    type: 'provincie';
    provincienaam: string;
    centroide_ll: string;
    weergavenaam: string;
    suggest: string[];
    geometrie_rd: string;
    provincieafkorting: string;
    centroide_rd: string;
    id: string;
    shards: string;
    _version_: number;
    typesortering: number;
    shard: string;
}
interface Gemeente {
    bron: 'Bestuurlijke Grenzen';
    identificatie: string;
    provinciecode: string;
    type: 'gemeente';
    provincienaam: string;
    centroide_ll: string;
    gemeentecode: string;
    weergavenaam: string;
    suggest: string[];
    geometrie_rd: string;
    provincieafkorting: string;
    centroide_rd: string;
    id: string;
    gemeentenaam: string;
    geometrie_ll: string;
    shards: string;
    _version_: number;
    typesortering: number;
    shard: string;
}
interface Woonplaats {
    bron: 'BAG';
    identificatie: string;
    geometrie_ll: string;
    provinciecode: string;
    woonplaatscode: string;
    type: 'woonplaats';
    woonplaatsnaam: string;
    provincienaam: string;
    centroide_ll: string;
    gemeentecode: string;
    rdf_seealso: string;
    weergavenaam: string;
    suggest: string[];
    geometrie_rd: string;
    provincieafkorting: string;
    centroide_rd: string;
    id: string;
    gemeentenaam: string;
    shards: string;
    _version_: number;
    typesortering: number;
    shard: string;
}
interface Weg {
    bron: 'BAG/NWB';
    woonplaatscode: string;
    type: 'weg';
    woonplaatsnaam: string;
    nwb_id: string;
    openbareruimtetype: string;
    gemeentecode: string;
    rdf_seealso: string;
    weergavenaam: string;
    suggest: string[];
    straatnaam_verkort: string;
    id: string;
    gemeentenaam: string;
    identificatie: string;
    openbareruimte_id: string;
    geometrie_ll: string;
    provinciecode: string;
    provincienaam: string;
    centroide_ll: string;
    geometrie_rd: string;
    provincieafkorting: string;
    centroide_rd: string;
    straatnaam: string;
    shards: string;
    _version_: number;
    typesortering: number;
    shard: string;
}
interface Postcode {
    bron: 'BAG';
    suggest: string[];
    woonplaatscode: string;
    type: 'postcode';
    woonplaatsnaam: string;
    openbareruimtetype: string;
    gemeentecode: string;
    weergavenaam: string;
    straatnaam_verkort: string;
    id: string;
    gemeentenaam: string;
    identificatie: string;
    openbareruimte_id: string;
    provinciecode: string;
    postcode: string;
    provincienaam: string;
    centroide_ll: string;
    geometrie_ll: string;
    provincieafkorting: string;
    geometrie_rd: string;
    centroide_rd: string;
    straatnaam: string;
    shards: string;
    _version_: number;
    typesortering: number;
    shard: string;
}
interface Adres {
    bron: 'BAG';
    woonplaatscode: string;
    type: 'adres';
    woonplaatsnaam: string;
    wijkcode: string;
    huis_nlt: string;
    openbareruimtetype: string;
    buurtnaam: string;
    gemeentecode: string;
    rdf_seealso: string;
    weergavenaam: string;
    suggest: string[];
    adrestype: string;
    straatnaam_verkort: string;
    id: string;
    gekoppeld_perceel: string[];
    gemeentenaam: string;
    buurtcode: string;
    wijknaam: string;
    identificatie: string;
    openbareruimte_id: string;
    waterschapsnaam: string;
    provinciecode: string;
    postcode: string;
    provincienaam: string;
    geometrie_ll: string;
    centroide_ll: string;
    nummeraanduiding_id: string;
    waterschapscode: string;
    adresseerbaarobject_id: string;
    huisnummer: number;
    huisletter?: string;
    huisnummertoevoeging?: string;
    provincieafkorting: string;
    geometrie_rd: string;
    centroide_rd: string;
    straatnaam: string;
    gekoppeld_appartement: string[];
    shards: string;
    _version_: number;
    typesortering: number;
    sortering: number;
    shard: string;
}
interface Perceel {
    bron: 'DKK';
    identificatie: string;
    geometrie_ll: string;
    kadastrale_aanduiding: string[];
    kadastrale_gemeentecode: string;
    kadastrale_sectie: string;
    kadastrale_grootte: number;
    suggest: string[];
    type: 'perceel';
    perceelnummer: number;
    centroide_ll: string;
    weergavenaam: string;
    geometrie_rd: string;
    kadastrale_gemeentenaam: string;
    centroide_rd: string;
    id: string;
    shards: string;
    _version_: number;
    typesortering: number;
    sortering: number;
    shard: string;
}
interface Wijk {
    bron: 'CBS';
    wijknaam: string;
    identificatie: string;
    geometrie_ll: string;
    provinciecode: string;
    type: 'wijk';
    provincienaam: string;
    wijkcode: string;
    centroide_ll: string;
    gemeentecode: string;
    weergavenaam: string;
    suggest: string[];
    geometrie_rd: string;
    provincieafkorting: string;
    centroide_rd: string;
    id: string;
    gemeentenaam: string;
    shards: string;
    _version_: number;
    typesortering: number;
    shard: string;
}
interface Buurt {
    bron: 'CBS';
    wijknaam: string;
    identificatie: string;
    geometrie_ll: string;
    provinciecode: string;
    type: 'buurt';
    provincienaam: string;
    wijkcode: string;
    centroide_ll: string;
    buurtnaam: string;
    gemeentecode: string;
    weergavenaam: string;
    suggest: string[];
    geometrie_rd: string;
    provincieafkorting: string;
    centroide_rd: string;
    id: string;
    gemeentenaam: string;
    buurtcode: string;
    shards: string;
    _version_: number;
    typesortering: number;
    shard: string;
}
interface Waterschap {
    bron: 'HWH';
    identificatie: string;
    waterschapsnaam: string;
    geometrie_ll: string;
    type: 'waterschap';
    centroide_ll: string;
    waterschapscode: string;
    weergavenaam: string;
    suggest: string[];
    centroide_rd: string;
    id: string;
    geometrie_rd: string;
    shards: string;
    _version_: number;
    typesortering: number;
    shard: string;
}
interface Appartementsrecht {
    bron: 'DKK';
    identificatie: string;
    geometrie_ll: string;
    kadastrale_aanduiding: string[];
    kadastrale_gemeentecode: string;
    kadastrale_sectie: string;
    volgnummer: number;
    type: 'appartementsrecht';
    perceelnummer: number;
    centroide_ll: string;
    weergavenaam: string;
    suggest: string[];
    geometrie_rd: string;
    kadastrale_gemeentenaam: string;
    centroide_rd: string;
    id: string;
    shards: string;
    _version_: number;
    typesortering: number;
    sortering: number;
    shard: string;
}
interface Hectometerpaal {
    bron: 'NWB';
    identificatie: string;
    hectometerletter: string;
    type: 'hectometerpaal';
    wegnummer: string;
    centroide_ll: string;
    geometrie_ll: string;
    hectometernummer: string;
    weergavenaam: string;
    suggest: string[];
    centroide_rd: string;
    geometrie_rd: string;
    id: string;
    shards: string;
    _version_: number;
    typesortering: number;
    shard: string;
}
type PlaceObject = Hectometerpaal | Appartementsrecht | Waterschap | Buurt | Wijk | Perceel | Adres | Postcode | Weg | Woonplaats | Gemeente | Provincie;
type ParsedPlaceObject = PlaceObject & {
    highlight: string;
    geometrie_ll: any;
    geometrie_rd: any;
    centroide_ll: any;
    centroide_rd: any;
};

declare class GeocoderService {
    private http;
    geocoderBaseUrl: string;
    constructor(http: HttpClient);
    suggest$(query: string, options?: SuggestOptions): rxjs.Observable<{
        places: SuggestObjectWithHighlight[];
    }>;
    lookup$(id: string, options?: LookupOptions): rxjs.Observable<ParsedPlaceObject>;
    free$(searchTerm: string, options?: SuggestOptions): rxjs.Observable<({
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "NWB";
        identificatie: string;
        hectometerletter: string;
        type: "hectometerpaal";
        wegnummer: string;
        hectometernummer: string;
        weergavenaam: string;
        suggest: string[];
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "DKK";
        identificatie: string;
        kadastrale_aanduiding: string[];
        kadastrale_gemeentecode: string;
        kadastrale_sectie: string;
        volgnummer: number;
        type: "appartementsrecht";
        perceelnummer: number;
        weergavenaam: string;
        suggest: string[];
        kadastrale_gemeentenaam: string;
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        sortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "HWH";
        identificatie: string;
        waterschapsnaam: string;
        type: "waterschap";
        waterschapscode: string;
        weergavenaam: string;
        suggest: string[];
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "CBS";
        wijknaam: string;
        identificatie: string;
        provinciecode: string;
        type: "buurt";
        provincienaam: string;
        wijkcode: string;
        buurtnaam: string;
        gemeentecode: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        gemeentenaam: string;
        buurtcode: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "CBS";
        wijknaam: string;
        identificatie: string;
        provinciecode: string;
        type: "wijk";
        provincienaam: string;
        wijkcode: string;
        gemeentecode: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        gemeentenaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "DKK";
        identificatie: string;
        kadastrale_aanduiding: string[];
        kadastrale_gemeentecode: string;
        kadastrale_sectie: string;
        kadastrale_grootte: number;
        suggest: string[];
        type: "perceel";
        perceelnummer: number;
        weergavenaam: string;
        kadastrale_gemeentenaam: string;
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        sortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "BAG";
        woonplaatscode: string;
        type: "adres";
        woonplaatsnaam: string;
        wijkcode: string;
        huis_nlt: string;
        openbareruimtetype: string;
        buurtnaam: string;
        gemeentecode: string;
        rdf_seealso: string;
        weergavenaam: string;
        suggest: string[];
        adrestype: string;
        straatnaam_verkort: string;
        id: string;
        gekoppeld_perceel: string[];
        gemeentenaam: string;
        buurtcode: string;
        wijknaam: string;
        identificatie: string;
        openbareruimte_id: string;
        waterschapsnaam: string;
        provinciecode: string;
        postcode: string;
        provincienaam: string;
        nummeraanduiding_id: string;
        waterschapscode: string;
        adresseerbaarobject_id: string;
        huisnummer: number;
        huisletter?: string;
        huisnummertoevoeging?: string;
        provincieafkorting: string;
        straatnaam: string;
        gekoppeld_appartement: string[];
        shards: string;
        _version_: number;
        typesortering: number;
        sortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "BAG";
        suggest: string[];
        woonplaatscode: string;
        type: "postcode";
        woonplaatsnaam: string;
        openbareruimtetype: string;
        gemeentecode: string;
        weergavenaam: string;
        straatnaam_verkort: string;
        id: string;
        gemeentenaam: string;
        identificatie: string;
        openbareruimte_id: string;
        provinciecode: string;
        postcode: string;
        provincienaam: string;
        provincieafkorting: string;
        straatnaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "BAG/NWB";
        woonplaatscode: string;
        type: "weg";
        woonplaatsnaam: string;
        nwb_id: string;
        openbareruimtetype: string;
        gemeentecode: string;
        rdf_seealso: string;
        weergavenaam: string;
        suggest: string[];
        straatnaam_verkort: string;
        id: string;
        gemeentenaam: string;
        identificatie: string;
        openbareruimte_id: string;
        provinciecode: string;
        provincienaam: string;
        provincieafkorting: string;
        straatnaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "BAG";
        identificatie: string;
        provinciecode: string;
        woonplaatscode: string;
        type: "woonplaats";
        woonplaatsnaam: string;
        provincienaam: string;
        gemeentecode: string;
        rdf_seealso: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        gemeentenaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "Bestuurlijke Grenzen";
        identificatie: string;
        provinciecode: string;
        type: "gemeente";
        provincienaam: string;
        gemeentecode: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        gemeentenaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "Bestuurlijke Grenzen";
        identificatie: string;
        provinciecode: string;
        type: "provincie";
        provincienaam: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    })[]>;
    reverse$(location: ReverseGeometry, options?: ReverseOptions): rxjs.Observable<({
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "NWB";
        identificatie: string;
        hectometerletter: string;
        type: "hectometerpaal";
        wegnummer: string;
        hectometernummer: string;
        weergavenaam: string;
        suggest: string[];
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "DKK";
        identificatie: string;
        kadastrale_aanduiding: string[];
        kadastrale_gemeentecode: string;
        kadastrale_sectie: string;
        volgnummer: number;
        type: "appartementsrecht";
        perceelnummer: number;
        weergavenaam: string;
        suggest: string[];
        kadastrale_gemeentenaam: string;
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        sortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "HWH";
        identificatie: string;
        waterschapsnaam: string;
        type: "waterschap";
        waterschapscode: string;
        weergavenaam: string;
        suggest: string[];
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "CBS";
        wijknaam: string;
        identificatie: string;
        provinciecode: string;
        type: "buurt";
        provincienaam: string;
        wijkcode: string;
        buurtnaam: string;
        gemeentecode: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        gemeentenaam: string;
        buurtcode: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "CBS";
        wijknaam: string;
        identificatie: string;
        provinciecode: string;
        type: "wijk";
        provincienaam: string;
        wijkcode: string;
        gemeentecode: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        gemeentenaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "DKK";
        identificatie: string;
        kadastrale_aanduiding: string[];
        kadastrale_gemeentecode: string;
        kadastrale_sectie: string;
        kadastrale_grootte: number;
        suggest: string[];
        type: "perceel";
        perceelnummer: number;
        weergavenaam: string;
        kadastrale_gemeentenaam: string;
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        sortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "BAG";
        woonplaatscode: string;
        type: "adres";
        woonplaatsnaam: string;
        wijkcode: string;
        huis_nlt: string;
        openbareruimtetype: string;
        buurtnaam: string;
        gemeentecode: string;
        rdf_seealso: string;
        weergavenaam: string;
        suggest: string[];
        adrestype: string;
        straatnaam_verkort: string;
        id: string;
        gekoppeld_perceel: string[];
        gemeentenaam: string;
        buurtcode: string;
        wijknaam: string;
        identificatie: string;
        openbareruimte_id: string;
        waterschapsnaam: string;
        provinciecode: string;
        postcode: string;
        provincienaam: string;
        nummeraanduiding_id: string;
        waterschapscode: string;
        adresseerbaarobject_id: string;
        huisnummer: number;
        huisletter?: string;
        huisnummertoevoeging?: string;
        provincieafkorting: string;
        straatnaam: string;
        gekoppeld_appartement: string[];
        shards: string;
        _version_: number;
        typesortering: number;
        sortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "BAG";
        suggest: string[];
        woonplaatscode: string;
        type: "postcode";
        woonplaatsnaam: string;
        openbareruimtetype: string;
        gemeentecode: string;
        weergavenaam: string;
        straatnaam_verkort: string;
        id: string;
        gemeentenaam: string;
        identificatie: string;
        openbareruimte_id: string;
        provinciecode: string;
        postcode: string;
        provincienaam: string;
        provincieafkorting: string;
        straatnaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "BAG/NWB";
        woonplaatscode: string;
        type: "weg";
        woonplaatsnaam: string;
        nwb_id: string;
        openbareruimtetype: string;
        gemeentecode: string;
        rdf_seealso: string;
        weergavenaam: string;
        suggest: string[];
        straatnaam_verkort: string;
        id: string;
        gemeentenaam: string;
        identificatie: string;
        openbareruimte_id: string;
        provinciecode: string;
        provincienaam: string;
        provincieafkorting: string;
        straatnaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "BAG";
        identificatie: string;
        provinciecode: string;
        woonplaatscode: string;
        type: "woonplaats";
        woonplaatsnaam: string;
        provincienaam: string;
        gemeentecode: string;
        rdf_seealso: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        gemeentenaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "Bestuurlijke Grenzen";
        identificatie: string;
        provinciecode: string;
        type: "gemeente";
        provincienaam: string;
        gemeentecode: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        gemeentenaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "Bestuurlijke Grenzen";
        identificatie: string;
        provinciecode: string;
        type: "provincie";
        provincienaam: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    })[]>;
    private formatPlaces;
    /**
     * Parse WKT in lookup response.
     */
    private formatLookupResponse;
    private formatReverseResponse;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<GeocoderService, never>;
    static ɵprov: _angular_core.ɵɵInjectableDeclaration<GeocoderService>;
}

declare class GeocoderHistoryService {
    private platformId;
    MAX_HISTORY_ENTRIES: number;
    HISTORY_LOCALSTORAGE_KEY: string;
    history$: BehaviorSubject<ParsedPlaceObject[]>;
    destroyRef: DestroyRef;
    saveToLocalStorage: rxjs.Subscription;
    constructor(platformId: any);
    getHistory(): ParsedPlaceObject[];
    updateHistory(lookupObject: ParsedPlaceObject): void;
    saveHistory(history: ParsedPlaceObject[]): void;
    retrieveHistory(): any;
    private isLocalStorageAvailable;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<GeocoderHistoryService, never>;
    static ɵprov: _angular_core.ɵɵInjectableDeclaration<GeocoderHistoryService>;
}

declare class GeocoderComponent implements OnInit, OnChanges {
    private geocoderService;
    private geocoderHistoryService;
    SEARCH_CHARACTER_THRESHOLD: number;
    readonly geocoderRef: _angular_core.Signal<ElementRef<any>>;
    readonly type: _angular_core.InputSignal<"hectometerpaal" | "appartementsrecht" | "waterschap" | "buurt" | "wijk" | "perceel" | "adres" | "postcode" | "weg" | "woonplaats" | "gemeente" | "provincie">;
    readonly searchInput: _angular_core.InputSignal<string>;
    readonly placeholder: _angular_core.InputSignal<string>;
    readonly resultCountLimit: _angular_core.InputSignal<number>;
    readonly province: _angular_core.InputSignal<string>;
    readonly fullscreen: _angular_core.InputSignal<boolean>;
    readonly microphone: _angular_core.InputSignal<boolean>;
    readonly boxshadow: _angular_core.InputSignal<boolean>;
    readonly borderradius: _angular_core.InputSignal<boolean>;
    readonly placeFound: _angular_core.OutputEmitterRef<ParsedPlaceObject>;
    readonly clearResults: _angular_core.OutputEmitterRef<any>;
    readonly query: _angular_core.OutputEmitterRef<string>;
    readonly freeSearchResults: _angular_core.OutputEmitterRef<ParsedPlaceObject[]>;
    readonly blur: _angular_core.OutputEmitterRef<any>;
    get hostGeocoderClass(): boolean;
    readonly hasFocus: _angular_core.WritableSignal<boolean>;
    speechRecognizer: any | undefined;
    formattedPlaceholder: _angular_core.Signal<string>;
    searchControl: FormControl<string>;
    readonly microphoneActive: _angular_core.WritableSignal<boolean>;
    userGpsLocation$: Subject<{
        lat: number;
        lon: number;
    }>;
    suggest$: rxjs.Observable<{
        places: SuggestObjectWithHighlight[];
    }>;
    reverseSuggest$: rxjs.Observable<({
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "NWB";
        identificatie: string;
        hectometerletter: string;
        type: "hectometerpaal";
        wegnummer: string;
        hectometernummer: string;
        weergavenaam: string;
        suggest: string[];
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "DKK";
        identificatie: string;
        kadastrale_aanduiding: string[];
        kadastrale_gemeentecode: string;
        kadastrale_sectie: string;
        volgnummer: number;
        type: "appartementsrecht";
        perceelnummer: number;
        weergavenaam: string;
        suggest: string[];
        kadastrale_gemeentenaam: string;
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        sortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "HWH";
        identificatie: string;
        waterschapsnaam: string;
        type: "waterschap";
        waterschapscode: string;
        weergavenaam: string;
        suggest: string[];
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "CBS";
        wijknaam: string;
        identificatie: string;
        provinciecode: string;
        type: "buurt";
        provincienaam: string;
        wijkcode: string;
        buurtnaam: string;
        gemeentecode: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        gemeentenaam: string;
        buurtcode: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "CBS";
        wijknaam: string;
        identificatie: string;
        provinciecode: string;
        type: "wijk";
        provincienaam: string;
        wijkcode: string;
        gemeentecode: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        gemeentenaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "DKK";
        identificatie: string;
        kadastrale_aanduiding: string[];
        kadastrale_gemeentecode: string;
        kadastrale_sectie: string;
        kadastrale_grootte: number;
        suggest: string[];
        type: "perceel";
        perceelnummer: number;
        weergavenaam: string;
        kadastrale_gemeentenaam: string;
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        sortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "BAG";
        woonplaatscode: string;
        type: "adres";
        woonplaatsnaam: string;
        wijkcode: string;
        huis_nlt: string;
        openbareruimtetype: string;
        buurtnaam: string;
        gemeentecode: string;
        rdf_seealso: string;
        weergavenaam: string;
        suggest: string[];
        adrestype: string;
        straatnaam_verkort: string;
        id: string;
        gekoppeld_perceel: string[];
        gemeentenaam: string;
        buurtcode: string;
        wijknaam: string;
        identificatie: string;
        openbareruimte_id: string;
        waterschapsnaam: string;
        provinciecode: string;
        postcode: string;
        provincienaam: string;
        nummeraanduiding_id: string;
        waterschapscode: string;
        adresseerbaarobject_id: string;
        huisnummer: number;
        huisletter?: string;
        huisnummertoevoeging?: string;
        provincieafkorting: string;
        straatnaam: string;
        gekoppeld_appartement: string[];
        shards: string;
        _version_: number;
        typesortering: number;
        sortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "BAG";
        suggest: string[];
        woonplaatscode: string;
        type: "postcode";
        woonplaatsnaam: string;
        openbareruimtetype: string;
        gemeentecode: string;
        weergavenaam: string;
        straatnaam_verkort: string;
        id: string;
        gemeentenaam: string;
        identificatie: string;
        openbareruimte_id: string;
        provinciecode: string;
        postcode: string;
        provincienaam: string;
        provincieafkorting: string;
        straatnaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "BAG/NWB";
        woonplaatscode: string;
        type: "weg";
        woonplaatsnaam: string;
        nwb_id: string;
        openbareruimtetype: string;
        gemeentecode: string;
        rdf_seealso: string;
        weergavenaam: string;
        suggest: string[];
        straatnaam_verkort: string;
        id: string;
        gemeentenaam: string;
        identificatie: string;
        openbareruimte_id: string;
        provinciecode: string;
        provincienaam: string;
        provincieafkorting: string;
        straatnaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "BAG";
        identificatie: string;
        provinciecode: string;
        woonplaatscode: string;
        type: "woonplaats";
        woonplaatsnaam: string;
        provincienaam: string;
        gemeentecode: string;
        rdf_seealso: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        gemeentenaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "Bestuurlijke Grenzen";
        identificatie: string;
        provinciecode: string;
        type: "gemeente";
        provincienaam: string;
        gemeentecode: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        gemeentenaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "Bestuurlijke Grenzen";
        identificatie: string;
        provinciecode: string;
        type: "provincie";
        provincienaam: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    })[]>;
    useMyLocationPlace: any;
    private historyWithTypeFilter$;
    tooFewCharacters$: rxjs.Observable<any[]>;
    places$: rxjs.Observable<any[] | SuggestObjectWithHighlight[] | ({
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "NWB";
        identificatie: string;
        hectometerletter: string;
        type: "hectometerpaal";
        wegnummer: string;
        hectometernummer: string;
        weergavenaam: string;
        suggest: string[];
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "DKK";
        identificatie: string;
        kadastrale_aanduiding: string[];
        kadastrale_gemeentecode: string;
        kadastrale_sectie: string;
        volgnummer: number;
        type: "appartementsrecht";
        perceelnummer: number;
        weergavenaam: string;
        suggest: string[];
        kadastrale_gemeentenaam: string;
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        sortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "HWH";
        identificatie: string;
        waterschapsnaam: string;
        type: "waterschap";
        waterschapscode: string;
        weergavenaam: string;
        suggest: string[];
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "CBS";
        wijknaam: string;
        identificatie: string;
        provinciecode: string;
        type: "buurt";
        provincienaam: string;
        wijkcode: string;
        buurtnaam: string;
        gemeentecode: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        gemeentenaam: string;
        buurtcode: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "CBS";
        wijknaam: string;
        identificatie: string;
        provinciecode: string;
        type: "wijk";
        provincienaam: string;
        wijkcode: string;
        gemeentecode: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        gemeentenaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "DKK";
        identificatie: string;
        kadastrale_aanduiding: string[];
        kadastrale_gemeentecode: string;
        kadastrale_sectie: string;
        kadastrale_grootte: number;
        suggest: string[];
        type: "perceel";
        perceelnummer: number;
        weergavenaam: string;
        kadastrale_gemeentenaam: string;
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        sortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "BAG";
        woonplaatscode: string;
        type: "adres";
        woonplaatsnaam: string;
        wijkcode: string;
        huis_nlt: string;
        openbareruimtetype: string;
        buurtnaam: string;
        gemeentecode: string;
        rdf_seealso: string;
        weergavenaam: string;
        suggest: string[];
        adrestype: string;
        straatnaam_verkort: string;
        id: string;
        gekoppeld_perceel: string[];
        gemeentenaam: string;
        buurtcode: string;
        wijknaam: string;
        identificatie: string;
        openbareruimte_id: string;
        waterschapsnaam: string;
        provinciecode: string;
        postcode: string;
        provincienaam: string;
        nummeraanduiding_id: string;
        waterschapscode: string;
        adresseerbaarobject_id: string;
        huisnummer: number;
        huisletter?: string;
        huisnummertoevoeging?: string;
        provincieafkorting: string;
        straatnaam: string;
        gekoppeld_appartement: string[];
        shards: string;
        _version_: number;
        typesortering: number;
        sortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "BAG";
        suggest: string[];
        woonplaatscode: string;
        type: "postcode";
        woonplaatsnaam: string;
        openbareruimtetype: string;
        gemeentecode: string;
        weergavenaam: string;
        straatnaam_verkort: string;
        id: string;
        gemeentenaam: string;
        identificatie: string;
        openbareruimte_id: string;
        provinciecode: string;
        postcode: string;
        provincienaam: string;
        provincieafkorting: string;
        straatnaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "BAG/NWB";
        woonplaatscode: string;
        type: "weg";
        woonplaatsnaam: string;
        nwb_id: string;
        openbareruimtetype: string;
        gemeentecode: string;
        rdf_seealso: string;
        weergavenaam: string;
        suggest: string[];
        straatnaam_verkort: string;
        id: string;
        gemeentenaam: string;
        identificatie: string;
        openbareruimte_id: string;
        provinciecode: string;
        provincienaam: string;
        provincieafkorting: string;
        straatnaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "BAG";
        identificatie: string;
        provinciecode: string;
        woonplaatscode: string;
        type: "woonplaats";
        woonplaatsnaam: string;
        provincienaam: string;
        gemeentecode: string;
        rdf_seealso: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        gemeentenaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "Bestuurlijke Grenzen";
        identificatie: string;
        provinciecode: string;
        type: "gemeente";
        provincienaam: string;
        gemeentecode: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        gemeentenaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "Bestuurlijke Grenzen";
        identificatie: string;
        provinciecode: string;
        type: "provincie";
        provincienaam: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    })[]>;
    readonly places: _angular_core.Signal<any[] | SuggestObjectWithHighlight[] | ({
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "NWB";
        identificatie: string;
        hectometerletter: string;
        type: "hectometerpaal";
        wegnummer: string;
        hectometernummer: string;
        weergavenaam: string;
        suggest: string[];
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "DKK";
        identificatie: string;
        kadastrale_aanduiding: string[];
        kadastrale_gemeentecode: string;
        kadastrale_sectie: string;
        volgnummer: number;
        type: "appartementsrecht";
        perceelnummer: number;
        weergavenaam: string;
        suggest: string[];
        kadastrale_gemeentenaam: string;
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        sortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "HWH";
        identificatie: string;
        waterschapsnaam: string;
        type: "waterschap";
        waterschapscode: string;
        weergavenaam: string;
        suggest: string[];
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "CBS";
        wijknaam: string;
        identificatie: string;
        provinciecode: string;
        type: "buurt";
        provincienaam: string;
        wijkcode: string;
        buurtnaam: string;
        gemeentecode: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        gemeentenaam: string;
        buurtcode: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "CBS";
        wijknaam: string;
        identificatie: string;
        provinciecode: string;
        type: "wijk";
        provincienaam: string;
        wijkcode: string;
        gemeentecode: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        gemeentenaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "DKK";
        identificatie: string;
        kadastrale_aanduiding: string[];
        kadastrale_gemeentecode: string;
        kadastrale_sectie: string;
        kadastrale_grootte: number;
        suggest: string[];
        type: "perceel";
        perceelnummer: number;
        weergavenaam: string;
        kadastrale_gemeentenaam: string;
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        sortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "BAG";
        woonplaatscode: string;
        type: "adres";
        woonplaatsnaam: string;
        wijkcode: string;
        huis_nlt: string;
        openbareruimtetype: string;
        buurtnaam: string;
        gemeentecode: string;
        rdf_seealso: string;
        weergavenaam: string;
        suggest: string[];
        adrestype: string;
        straatnaam_verkort: string;
        id: string;
        gekoppeld_perceel: string[];
        gemeentenaam: string;
        buurtcode: string;
        wijknaam: string;
        identificatie: string;
        openbareruimte_id: string;
        waterschapsnaam: string;
        provinciecode: string;
        postcode: string;
        provincienaam: string;
        nummeraanduiding_id: string;
        waterschapscode: string;
        adresseerbaarobject_id: string;
        huisnummer: number;
        huisletter?: string;
        huisnummertoevoeging?: string;
        provincieafkorting: string;
        straatnaam: string;
        gekoppeld_appartement: string[];
        shards: string;
        _version_: number;
        typesortering: number;
        sortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "BAG";
        suggest: string[];
        woonplaatscode: string;
        type: "postcode";
        woonplaatsnaam: string;
        openbareruimtetype: string;
        gemeentecode: string;
        weergavenaam: string;
        straatnaam_verkort: string;
        id: string;
        gemeentenaam: string;
        identificatie: string;
        openbareruimte_id: string;
        provinciecode: string;
        postcode: string;
        provincienaam: string;
        provincieafkorting: string;
        straatnaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "BAG/NWB";
        woonplaatscode: string;
        type: "weg";
        woonplaatsnaam: string;
        nwb_id: string;
        openbareruimtetype: string;
        gemeentecode: string;
        rdf_seealso: string;
        weergavenaam: string;
        suggest: string[];
        straatnaam_verkort: string;
        id: string;
        gemeentenaam: string;
        identificatie: string;
        openbareruimte_id: string;
        provinciecode: string;
        provincienaam: string;
        provincieafkorting: string;
        straatnaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "BAG";
        identificatie: string;
        provinciecode: string;
        woonplaatscode: string;
        type: "woonplaats";
        woonplaatsnaam: string;
        provincienaam: string;
        gemeentecode: string;
        rdf_seealso: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        gemeentenaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "Bestuurlijke Grenzen";
        identificatie: string;
        provinciecode: string;
        type: "gemeente";
        provincienaam: string;
        gemeentecode: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        gemeentenaam: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    } | {
        highlight: string;
        geometrie_ll: geojson.GeoJSON;
        geometrie_rd: geojson.GeoJSON;
        centroide_rd: geojson.GeoJSON;
        centroide_ll: geojson.GeoJSON;
        bron: "Bestuurlijke Grenzen";
        identificatie: string;
        provinciecode: string;
        type: "provincie";
        provincienaam: string;
        weergavenaam: string;
        suggest: string[];
        provincieafkorting: string;
        id: string;
        shards: string;
        _version_: number;
        typesortering: number;
        shard: string;
    })[]>;
    foundPlace$: BehaviorSubject<any>;
    selectedIndex: number;
    readonly lookupResponseFound: _angular_core.WritableSignal<boolean>;
    clickout(event: any): void;
    constructor(geocoderService: GeocoderService, geocoderHistoryService: GeocoderHistoryService);
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    private suggest;
    private reverse;
    lookup(id: string): Promise<void>;
    reverseGeocode(): Promise<void>;
    free(): Promise<void>;
    clear(event: Event): void;
    clearPlaces(): void;
    handleSuggestClick(id: 'gps' | string): Promise<void>;
    handleEnter(places: SuggestObjectWithHighlight[]): void;
    reachedThreshold$: rxjs.Observable<boolean>;
    noPlacesFound$: rxjs.Observable<boolean>;
    noResult$: rxjs.Observable<boolean>;
    readonly noResult: _angular_core.Signal<boolean>;
    readonly isNoResultsFound: _angular_core.Signal<boolean>;
    fillInput(content: string, emitEvent?: boolean): void;
    isHighlighted(i: number): boolean;
    moveUp(): void;
    moveDown(places: SuggestObjectWithHighlight[]): void;
    resetIndex(): void;
    canQuery(): boolean;
    canClear(): boolean;
    formatPlaceholder(placeholder: string): string;
    showSuggestions(): void;
    private getSpeechRecognition;
    speechToText(event: any): any;
    private hideResults;
    private getGpsLocation;
    private formatSearchTerm;
    private removeErrorCausingCharacters;
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<GeocoderComponent, never>;
    static ɵcmp: _angular_core.ɵɵComponentDeclaration<GeocoderComponent, "angular-geocoder", never, { "type": { "alias": "type"; "required": false; "isSignal": true; }; "searchInput": { "alias": "searchInput"; "required": false; "isSignal": true; }; "placeholder": { "alias": "placeholder"; "required": false; "isSignal": true; }; "resultCountLimit": { "alias": "resultCountLimit"; "required": false; "isSignal": true; }; "province": { "alias": "province"; "required": false; "isSignal": true; }; "fullscreen": { "alias": "fullscreen"; "required": false; "isSignal": true; }; "microphone": { "alias": "microphone"; "required": false; "isSignal": true; }; "boxshadow": { "alias": "boxshadow"; "required": false; "isSignal": true; }; "borderradius": { "alias": "borderradius"; "required": false; "isSignal": true; }; }, { "placeFound": "placeFound"; "clearResults": "clearResults"; "query": "query"; "freeSearchResults": "freeSearchResults"; "blur": "blur"; }, never, never, false, never>;
}

declare class GeocoderModule {
    static ɵfac: _angular_core.ɵɵFactoryDeclaration<GeocoderModule, never>;
    static ɵmod: _angular_core.ɵɵNgModuleDeclaration<GeocoderModule, [typeof GeocoderComponent], [typeof i2.ReactiveFormsModule], [typeof GeocoderComponent]>;
    static ɵinj: _angular_core.ɵɵInjectorDeclaration<GeocoderModule>;
}

export { GeocoderComponent, GeocoderModule, GeocoderService };
